@@ -17,7 +17,8 @@ from .lip import LIP
 from .ade20k import ADE20K
 from .lfw import LFW
 from .cityscape import Cityscape
+from .mpii import MPII
 
 __all__ = [
-  'Mnist', 'Cifar10', 'Cifar100', 'ImageNet', 'Pascal2007', 'Pascal2012', 'COCO2017', 'InterHand26M', 'LSP', 'VisalSO', 'VGGFace', 'FLIC', 'LIP', 'ADE20K', 'LFW', 'Cityscape','Dataset'
+  'Mnist', 'Cifar10', 'Cifar100', 'ImageNet', 'Pascal2007', 'Pascal2012', 'COCO2017', 'InterHand26M', 'LSP', 'VisalSO', 'VGGFace', 'FLIC', 'LIP', 'ADE20K', 'LFW', 'Cityscape', 'MPII', 'Dataset'
 ]
