@@ -17,6 +17,7 @@ from ...utils.fs import maybe_here
 from .dataset import Dataset
 import copy
 import time
+from filelock import FileLock
 
 __all__ = ['Cifar10', 'Cifar100']
 CIFAR_10_URL = 'http://www.cs.toronto.edu/~kriz/cifar-10-python.tar.gz'
@@ -85,21 +86,11 @@ class CifarBase(Dataset):
       cifar_foldername = 'cifar-100-python'
 
     data_url = CIFAR_10_URL if cifar_classnum == 10 else CIFAR_100_URL
-    if os.environ.get('LOCAL_RANK', 0) == 0:
+    lock = FileLock('DATASET.lock')
+    with lock:
       if not os.path.exists(os.path.join(self.dir, cifar_foldername)):
         # 数据集不存在，需要重新下载，并创建标记
         self.download(self.dir, default_url=data_url, auto_untar=True, is_gz=True)
-        os.system('touch DATASET_IS_READY')     
-      else:
-        # 数据集存在，创建标记
-        if not os.path.exists('DATASET_IS_READY'):
-          os.system('touch DATASET_IS_READY')
-    else:
-      while True:
-        # 等待直到存在指定文件
-        if os.path.exists('DATASET_IS_READY'):
-          break
-        time.sleep(5)
 
     fnames = get_filenames(self.dir, self.cifar_classnum)
     if self.train_or_test == 'train':
