@@ -5,6 +5,7 @@ from torch import nn
 from antgo.framework.helper.models.builder import MODELS, build_backbone, build_head, build_neck
 from antgo.framework.helper.runner import BaseModule
 import numpy as np
+import torch.nn.functional as F
 
 
 @MODELS.register_module()
@@ -23,12 +24,16 @@ class KeypointNet(BaseModule):
         self.ohem = True
         self.cls_criterion = torch.nn.BCEWithLogitsLoss(reduction='none' if self.ohem else 'mean')
         self.criterion = torch.nn.MSELoss(reduction='none' if self.ohem else 'mean')
+        self.offset_loss_weight = 0.1
+        self.heatmap_loss_weight = 1.0
+        if train_cfg is not None:
+            self.offset_loss_weight = train_cfg.get('offset_loss_weight', 0.1)
+            self.heatmap_loss_weight = train_cfg.get('heatmap_loss_weight', 1.0)
     
     def _loss(self, pred_heatmap, pred_offset_xy, gt_heatmap, joint_mask, heatmap_mask, offset_x, offset_y):
         hard_weight = 2
         mid_weight = 1
         easy_weight = 0.5
-
         loss_hm = self.cls_criterion(pred_heatmap, gt_heatmap)
 
         joint_num = pred_heatmap.shape[1]
@@ -85,8 +90,8 @@ class KeypointNet(BaseModule):
         )
 
         outloss = dict()
-        outloss["loss_uv_hm"] = loss_hm
-        outloss["loss_xy_offset"] = 0.1 * (loss_offx + loss_offy)
+        outloss["loss_uv_hm"] = self.heatmap_loss_weight * loss_hm
+        outloss["loss_xy_offset"] = self.offset_loss_weight * (loss_offx + loss_offy)
         return outloss
 
     def forward_train(self, image, heatmap, offset_x, offset_y, heatmap_weight, joints_vis, **kwargs):
@@ -140,7 +145,9 @@ class KeypointNet(BaseModule):
         offset_y = offset_y.detach().cpu().numpy()
 
         preds, score = self.get_max_pred_batch(preds, offset_x, offset_y)
-        pred_gt_hm = np.concatenate([preds * (image_h/heatmap_h), score], axis=2)
+        preds[:,:, 0] = preds[:,:, 0] * (image_w/heatmap_w)
+        preds[:,:, 1] = preds[:,:, 1] * (image_h/heatmap_h)
+        pred_gt_hm = np.concatenate([preds, score], axis=2)
         results = {
             'pred_joints2d': [sample_joint2d for sample_joint2d in pred_gt_hm],
         }
@@ -148,6 +155,7 @@ class KeypointNet(BaseModule):
 
     def onnx_export(self, image):
         output = self.backbone(image)   # x32,x16,x8,x4
-        output = self.head(output)      # uv_heatmap, uv_off
-  
-        return output
\ No newline at end of file
+        heatmap, offset = self.head(output) # uv_heatmap, uv_off
+        heatmap = torch.sigmoid(heatmap)
+        heatmap = F.max_pool2d(heatmap, 3, stride=1, padding=(3 - 1) // 2)
+        return heatmap, offset
\ No newline at end of file
