@@ -15,6 +15,7 @@ from antgo.pipeline.hparam import param_scope
 from antgo.pipeline.hparam import dynamic_dispatch
 from antgo.pipeline.functional.common.config import *
 import numpy as np
+import json
 
 read_camera = DataCollection.read_camera
 read_video = DataCollection.read_video
@@ -32,6 +33,36 @@ def glob(*arg):  # pragma: no cover
     return DataFrame.from_glob(*arg).map(lambda x: Entity(**{index: x}))
 
 
+@dynamic_dispatch
+def json_dc(*args):
+  index = param_scope()._index
+
+  def inner():
+    for json_path in args:
+      with open(json_path, 'r') as fp:
+        info_list = json.load(fp)
+        for data in info_list:
+          yield Entity(**{index: data})
+
+  return DataFrame(inner())
+
+
+@dynamic_dispatch
+def txt_dc(*args):
+  index = param_scope()._index
+
+  def inner():
+    for json_path in args:
+      with open(json_path, 'r') as fp:
+        string = f.readline()
+        while string:
+            data = json.loads(string)
+            string = f.readline()
+            yield Entity(**{index: data})
+
+  return DataFrame(inner())
+
+
 @dynamic_dispatch
 def video_dc(*args):
     index = param_scope()._index
@@ -91,14 +122,20 @@ def _placeholder(*arg):
     for ii,xx in zip(index, arg):
       
       data_type = -1
-      if xx.dtype == np.float32:
-        data_type = 6
-      elif xx.dtype == np.float64:
-        data_type = 7
-      elif xx.dtype == np.int32:
-        data_type = 4
-      elif xx.dtype == np.uint8:
-        data_type = 1
+      data_shape = []
+      if isinstance(xx, np.ndarray):
+        data_shape = list(xx.shape)
+        if xx.dtype == np.float32:
+          data_type = 6
+        elif xx.dtype == np.float64:
+          data_type = 7
+        elif xx.dtype == np.int32:
+          data_type = 4
+        elif xx.dtype == np.uint8:
+          data_type = 1
+      elif isinstance(xx, str):
+        data_shape = []
+        data_type = 11
 
       if data_type < 0:
         print('placeholder type abnormal.')
@@ -111,7 +148,7 @@ def _placeholder(*arg):
           'memory_type': 2,     # CPU_BUFFER
           'data_format': 1000,  # AUTO
           'data_type': data_type,        # EAGLEEYE_UCHAR, EAGLEEYE_FLOAT
-          'shape': list(xx.shape),  # 
+          'shape': data_shape,  # 
         }
       )
 
@@ -121,13 +158,19 @@ def _placeholder(*arg):
     )
   else:
     for ii, xx in zip([index], arg):
+      data_shape = []
       data_type = -1
-      if xx.dtype == np.float32:
-        data_type = 6
-      elif xx.dtype == np.int32:
-        data_type = 4
-      elif xx.dtype == np.uint8:
-        data_type = 1
+      if isinstance(xx, np.ndarray):
+        data_shape = list(xx.shape)
+        if xx.dtype == np.float32:
+          data_type = 6
+        elif xx.dtype == np.int32:
+          data_type = 4
+        elif xx.dtype == np.uint8:
+          data_type = 1
+      elif isinstance(xx, str):
+        data_shape = []
+        data_type = 11
 
       if data_type < 0:
         print('placeholder type abnormal.')
@@ -140,7 +183,7 @@ def _placeholder(*arg):
           'memory_type': 2,               # CPU_BUFFER
           'data_format': 1000,            # AUTO
           'data_type': data_type,         # EAGLEEYE_UCHAR, EAGLEEYE_FLOAT
-          'shape': list(xx.shape),        # 
+          'shape': data_shape,        # 
         }
       )
 
