@@ -31,6 +31,10 @@ class DatasetMixin:
             raise FileNotFoundError(f'There is no files with {args}.')
         return cls(files)
 
+    @classmethod
+    def placeholder(cls, *args):
+        return cls(list(args))
+
     @classmethod
     def read_json(cls, json_path: Union[str, Path], encoding: str = 'utf-8'):
         import json
