@@ -2,9 +2,14 @@ from .extract import (extract_from_videos, extract_from_images, extract_from_sam
 from .browser_funcs import (browser_images)
 from .filter_funcs import (filter_by_tags)
 from .package import (package_to_kv, package_to_tfrecord)
-from .download_funcs import (download_from_baidu, download_from_bing, download_from_vcg)
+from .download_funcs import (download_from_baidu, download_from_bing, download_from_vcg, download_from_aliyun)
 from .label_funcs import (label_to_studio, label_from_studio, label_start, label_from_native, label_to_merge)
 from .share_funcs import (share_data_func)
+from .upload_funcs import (upload_to_aliyun)
+from .check_device import (check_device_info)
+from .ls_funcs import (ls_from_aliyun)
+from .operate_funcs import (operate_on_running_status)
+
 __all__ = [
     'extract_from_videos', 
     'extract_from_images', 
@@ -18,10 +23,15 @@ __all__ = [
     'download_from_baidu',
     'download_from_bing',
     'download_from_vcg',
+    'download_from_aliyun',
+    'upload_to_aliyun',
     'label_to_studio',
     'label_from_studio',
     'label_from_native',
     'label_start',
     'label_to_merge',
-    'share_data_func'
+    'share_data_func',
+    'check_device_info',
+    'ls_from_aliyun',
+    'operate_on_running_status'
 ]
\ No newline at end of file
